#ifndef NT2_INCLUDE_CONSTANTS_MINDENORMAL_HPP_INCLUDED
#define NT2_INCLUDE_CONSTANTS_MINDENORMAL_HPP_INCLUDED

#include <nt2/constant/include/constants/mindenormal.hpp>

#endif
